==> haskell-authenticate-1.3.3.2-75-i686.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.2
id: authenticate-1.3.3.2-75L9fYCCGqI5NFNuuf1p2S
key: authenticate-1.3.3.2-75L9fYCCGqI5NFNuuf1p2S
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: a04339d0d4049a52f65fb03abce9b8df
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/authenticate-1.3.3.2
hs-libraries: HSauthenticate-1.3.3.2-75L9fYCCGqI5NFNuuf1p2S
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS containers-0.5.7.1
    http-conduit-2.2.3.1-Da0xpFQXFRzKlX6wh7ZvuZ
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    tagstream-conduit-0.5.5.3-AKVje3f3O7ZBHUkCl33TNk
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    xml-conduit-1.4.0.4-4JMNsrmqa8CJ6lSm2Ik1gQ
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.3.2-76-i686.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.2
id: authenticate-1.3.3.2-JHRgG5Q1pIKCbASNlAoxuG
key: authenticate-1.3.3.2-JHRgG5Q1pIKCbASNlAoxuG
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: e4fe9c1e3fdf3fe8b34482a79fa5c327
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/authenticate-1.3.3.2
hs-libraries: HSauthenticate-1.3.3.2-JHRgG5Q1pIKCbASNlAoxuG
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS containers-0.5.7.1
    http-conduit-2.2.3.1-AZ9OyjWSKnlGDxjQabBNJd
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    tagstream-conduit-0.5.5.3-AKVje3f3O7ZBHUkCl33TNk
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    xml-conduit-1.4.0.4-4JMNsrmqa8CJ6lSm2Ik1gQ
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
